summaryrefslogtreecommitdiff
path: root/tests/test_shortcut.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test_shortcut.c')
-rw-r--r--tests/test_shortcut.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/tests/test_shortcut.c b/tests/test_shortcut.c
index 96a5b74..7365ef0 100644
--- a/tests/test_shortcut.c
+++ b/tests/test_shortcut.c
@@ -328,14 +328,14 @@ test_shortcut_keypath_toggle_and_back(void) {
static void
test_shortcut_full_table_registered(void) {
static const char *ACTIONS[] = {
- "win.prev", "win.next", "win.first", "win.last",
- "win.open", "win.quit", "win.trash", "win.delete",
- "win.undo", "win.toggle-view", "win.mark", "win.mark-all",
- "win.shortcuts", "win.zoom-in", "win.zoom-out", "win.fullscreen",
- "win.slideshow", "win.info", "win.back", "win.enhance",
- "win.enhance-save", "win.enhance-1", "win.enhance-2", "win.enhance-3",
- "win.enhance-4", "win.enhance-5", "win.enhance-6", "win.enhance-7",
- "win.enhance-8",
+ "win.prev", "win.next", "win.first", "win.last",
+ "win.open", "win.quit", "win.trash", "win.delete",
+ "win.undo", "win.toggle-view", "win.mark", "win.mark-all",
+ "win.mark-range", "win.shortcuts", "win.zoom-in", "win.zoom-out",
+ "win.fullscreen", "win.slideshow", "win.info", "win.back",
+ "win.enhance", "win.enhance-save", "win.enhance-1", "win.enhance-2",
+ "win.enhance-3", "win.enhance-4", "win.enhance-5", "win.enhance-6",
+ "win.enhance-7", "win.enhance-8",
};
GgazeWindow *p_win = new_window();
GtkShortcutController *p_sc = find_shortcut_controller(GTK_WIDGET(p_win));
@@ -345,9 +345,9 @@ test_shortcut_full_table_registered(void) {
g_assert_nonnull(p_s);
g_object_unref(p_s);
}
/* The SHORTCUTS[] table has 25 rows now (some actions appear twice, e.g.
* win.prev for h and Left; win.zoom-in for plus and equal). */
- g_assert_cmpint(g_list_model_get_n_items(G_LIST_MODEL(p_sc)), ==, 33);
+ g_assert_cmpint(g_list_model_get_n_items(G_LIST_MODEL(p_sc)), ==, 34);
g_object_unref(p_sc);
g_object_unref(p_win);
drain_main(200);
@@ -345,9 +345,9 @@ test_shortcut_full_table_registered(void) {
g_object_unref(p_s);
}
- /* The SHORTCUTS[] table has 25 rows now (some actions appear twice, e.g.
+ /* The SHORTCUTS[] table has 34 rows now (some actions appear twice, e.g.
* win.prev for h and Left; win.zoom-in for plus and equal). */